pub fn is_encoded(input: &str) -> bool
Quick check if a string appears to be Namecode-encoded.
This checks if the string starts with the _N_ prefix. Note: This doesn’t validate that the encoding is well-formed.
_N_